@@ -85,6 +85,8 @@ class Generator
         void declarations();
 
     private:
+        static std::string filename(std::string const &path);
+
         void DFAbases(std::ostream &out) const;
         static std::string outDFAbase(std::string const &startState,
                                       size_t offset);
@@ -108,6 +110,7 @@ class Generator
         void inputInterface(std::ostream &out) const;
         void insert(std::ostream &out) const;
         void insertSstream(std::ostream &out) const;
+        void interactiveDecl(std::ostream &out) const;
         void interactiveInit(std::ostream &out) const;
         void interactiveLex(std::ostream &out) const;
         void key(std::ostream &out) const;
