@@ -106,7 +106,7 @@ private:
     Input           d_input;
     std::string     d_matched;              // matched characters
     bool            d_return;               // return after a rule's action 
-    bool            d_more;                 // set to true by more()
+    bool            d_more = false;         // set to true by more()
 
 protected:
     std::istream   *d_in__;
@@ -145,6 +145,8 @@ $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
 
 $ignoreInteractive END      end ignored section by generator/filter.cc
 
+$insert interactiveDecl
+
 protected:
     \@Base(std::istream &in, std::ostream &out);
 $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
@@ -189,7 +191,6 @@ $ignoreInteractive END      end ignored section by generator/filter.cc
         // otherwise.
 
     ActionType__    actionType__(size_t range); // next action
-    bool            interactiveLine__();        // refresh an interactive line
     bool            return__();                 // 'return' from codeblock
     size_t          matched__(size_t ch);       // handles a matched rule
     size_t          getRange__(int ch);         // convert char to range
